@@ -57,7 +57,10 @@ void HomeScreenState::init()
         // the animation runs too long to connect to QPropertyAnimation::finished
         // instead just have the end behaviour execute once we are 90% through
         if (m_appDrawerOpenProgress < 0.1) {
-            setViewState(ViewState::PageView);
+            if (m_viewState == ViewState::AppDrawerView) {
+                // confirm view state is still AppDrawerView before setting to prevent oddities
+                setViewState(ViewState::PageView);
+            }
             Q_EMIT appDrawerClosed();
         }
     });
@@ -517,12 +520,17 @@ void HomeScreenState::setFolderOpenProgress(qreal folderOpenProgress)
     }
 }
 
-FolioApplicationFolder *HomeScreenState::currentFolder() const
+FolioApplicationFolder::Ptr HomeScreenState::currentFolder() const
 {
     return m_currentFolder;
 }
 
-void HomeScreenState::setCurrentFolder(FolioApplicationFolder *folder)
+FolioApplicationFolder *HomeScreenState::currentFolderRaw() const
+{
+    return m_currentFolder.get();
+}
+
+void HomeScreenState::setCurrentFolder(FolioApplicationFolder::Ptr folder)
 {
     if (m_currentFolder != folder) {
         m_currentFolder = folder;
@@ -564,16 +572,6 @@ qreal HomeScreenState::appDrawerOpenProgress()
     return m_appDrawerOpenProgress;
 }
 
-void HomeScreenState::setAppDrawerOpenProgress(qreal appDrawerOpenProgress)
-{
-    if (appDrawerOpenProgress == m_appDrawerOpenProgress) {
-        return;
-    }
-
-    m_appDrawerOpenProgress = appDrawerOpenProgress;
-    Q_EMIT appDrawerOpenProgressChanged();
-}
-
 qreal HomeScreenState::appDrawerY()
 {
     return m_appDrawerY;
@@ -581,12 +579,10 @@ qreal HomeScreenState::appDrawerY()
 
 void HomeScreenState::setAppDrawerY(qreal appDrawerY)
 {
-    if (m_appDrawerY != appDrawerY) {
-        m_appDrawerY = appDrawerY;
-        Q_EMIT appDrawerYChanged();
-    }
-
-    setAppDrawerOpenProgress(1 - qBound(0.0, m_appDrawerY, APP_DRAWER_OPEN_DIST) / APP_DRAWER_OPEN_DIST);
+    m_appDrawerY = appDrawerY;
+    m_appDrawerOpenProgress = 1 - qBound(0.0, m_appDrawerY, APP_DRAWER_OPEN_DIST) / APP_DRAWER_OPEN_DIST;
+    Q_EMIT appDrawerYChanged();
+    Q_EMIT appDrawerOpenProgressChanged();
 }
 
 qreal HomeScreenState::searchWidgetOpenProgress()
@@ -594,29 +590,17 @@ qreal HomeScreenState::searchWidgetOpenProgress()
     return m_searchWidgetOpenProgress;
 }
 
-void HomeScreenState::setSearchWidgetOpenProgress(qreal progress)
-{
-    if (m_searchWidgetOpenProgress == progress) {
-        return;
-    }
-
-    m_searchWidgetOpenProgress = progress;
-    Q_EMIT searchWidgetOpenProgressChanged();
-}
-
 qreal HomeScreenState::searchWidgetY()
 {
-    return m_searchWidgetY;
+    return m_searchWidgetOpenProgress;
 }
 
 void HomeScreenState::setSearchWidgetY(qreal searchWidgetY)
 {
-    if (m_searchWidgetY != searchWidgetY) {
-        m_searchWidgetY = searchWidgetY;
-        Q_EMIT searchWidgetYChanged();
-    }
-
-    setSearchWidgetOpenProgress(1 - qBound(0.0, m_searchWidgetY, SEARCH_WIDGET_OPEN_DIST) / SEARCH_WIDGET_OPEN_DIST);
+    m_searchWidgetY = searchWidgetY;
+    m_searchWidgetOpenProgress = 1 - qBound(0.0, m_searchWidgetY, SEARCH_WIDGET_OPEN_DIST) / SEARCH_WIDGET_OPEN_DIST;
+    Q_EMIT searchWidgetYChanged();
+    Q_EMIT searchWidgetOpenProgressChanged();
 }
 
 qreal HomeScreenState::delegateDragX()
@@ -686,17 +670,17 @@ FolioDelegate *HomeScreenState::getPageDelegateAt(int page, int row, int column)
         return nullptr;
     }
 
-    FolioDelegate *delegate = pageModel->getDelegate(row, column);
+    FolioDelegate::Ptr delegate = pageModel->getDelegate(row, column);
     if (!delegate) {
         return nullptr;
     }
 
-    return delegate;
+    return delegate.get();
 }
 
 FolioDelegate *HomeScreenState::getFavouritesDelegateAt(int position)
 {
-    return m_homeScreen->favouritesModel()->getEntryAt(position);
+    return m_homeScreen->favouritesModel()->getEntryAt(position).get();
 }
 
 FolioDelegate *HomeScreenState::getFolderDelegateAt(int position)
@@ -705,7 +689,7 @@ FolioDelegate *HomeScreenState::getFolderDelegateAt(int position)
         return nullptr;
     }
 
-    return m_currentFolder->applications()->getDelegate(position);
+    return m_currentFolder->applications()->getDelegate(position).get();
 }
 
 QPointF HomeScreenState::getPageDelegateScreenPosition(int page, int row, int column)
@@ -823,7 +807,7 @@ void HomeScreenState::goToFolderPage(int page, bool snap)
 
 void HomeScreenState::openFolder(qreal delegateX, qreal delegateY, FolioApplicationFolder *folder)
 {
-    setCurrentFolder(folder);
+    setCurrentFolder(folder->shared_from_this());
 
     m_openFolderAnim->stop();
     m_closeFolderAnim->stop();
@@ -990,6 +974,11 @@ void HomeScreenState::swipeEnded()
     setSwipeState(SwipeState::None);
 }
 
+void HomeScreenState::swipeCancelled()
+{
+    setSwipeState(SwipeState::None);
+}
+
 void HomeScreenState::swipeMoved(qreal totalDeltaX, qreal totalDeltaY, qreal deltaX, qreal deltaY)
 {
     m_movingUp = deltaY > 0;
